server

package
v0.0.0-...-5e7643e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 15, 2026 License: GPL-3.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Server

type Server struct {
	Addr string
	App  *fiber.App
}

func NewServer

func NewServer(service *service.Service, pool *pgxpool.Pool) *Server

Directories

Path Synopsis
api
Package api contains all api routes
Package api contains all api routes
v1
Package v1 contains the first version of the public API
Package v1 contains the first version of the public API
Package dto contains all data transferable objects
Package dto contains all data transferable objects
Package service provides all business logic required by the api and converts between dto and models
Package service provides all business logic required by the api and converts between dto and models

Jump to