Documentation
¶
Overview ¶
Package zauth interacts with the Zeus zauth service
Index ¶
- Variables
- func Init()
- type Provider
- func (p *Provider) BeginAuth(state string) (goth.Session, error)
- func (p *Provider) Debug(_ bool)
- func (p *Provider) FetchUser(gothSession goth.Session) (goth.User, error)
- func (p *Provider) Name() string
- func (p *Provider) RefreshToken(_ string) (*oauth2.Token, error)
- func (p *Provider) RefreshTokenAvailable() bool
- func (p *Provider) SetName(name string)
- func (p *Provider) UnmarshalSession(data string) (goth.Session, error)
- type Session
- type User
Constants ¶
This section is empty.
Variables ¶
var C *client
Functions ¶
Types ¶
type Provider ¶
type Provider struct {
// contains filtered or unexported fields
}
Provider is the implementation of `goth.Provider` for accessing Zauth
func (*Provider) FetchUser ¶
FetchUser will go to Zauth and access basic information about the user.
func (*Provider) RefreshToken ¶
RefreshToken get new access token based on the refresh token Not implemented for Zauth
func (*Provider) RefreshTokenAvailable ¶
RefreshTokenAvailable returns if refresh tokens are supported This is not the case for Zauth
type Session ¶
Session is the implementation of `goth.Session` for storing data during the auth process with Zauth
func (*Session) Authorize ¶
Authorize the session with Zauth and return the access token to be stored for future use
func (*Session) GetAuthURL ¶
GetAuthURL will return the URL set by calling the `BeginAuth` function on the Zauth provider.
Click to show internal directories.
Click to hide internal directories.